@@ -6,19 +6,11 @@ import os.path
 import math
 
 from colorama import init, Fore, Style
+init(autoreset=True)
 
 from term2048 import keypress
 from term2048.board import Board
 
-# PY3 compat
-try:
-    xrange
-except NameError:
-    xrange = range
-
-
-init(autoreset=True)
-
 
 class Game(object):
     """
@@ -62,6 +54,7 @@ class Game(object):
     SCORES_FILE = '%s/.term2048.scores' % os.path.expanduser('~')
 
     def __init__(self, scores_file=SCORES_FILE, colors=COLORS,
+            clear_screen=True,
             mode=None, azmode=False, **kws):
         """
         Create a new game.
@@ -75,10 +68,13 @@ class Game(object):
         self.board = Board(**kws)
         self.score = 0
         self.scores_file = scores_file
+        self.clear_screen = clear_screen
+
         self.__colors = colors
+        self.__azmode = azmode
+
         self.loadBestScore()
         self.adjustColors(mode)
-        self.__azmode = azmode
 
     def adjustColors(self, mode='dark'):
         """
@@ -141,11 +137,14 @@ class Game(object):
 
     def loop(self):
         """
-        main game loop
+        main game loop. returns the final score.
         """
         try:
             while True:
-                os.system(Game.__clear)
+                if self.clear_screen:
+                    os.system(Game.__clear)
+                else:
+                    print("\n")
                 print(self.__str__(margins={'left':4, 'top':4, 'bottom':4}))
                 if self.board.won() or not self.board.canMove():
                     break
@@ -158,6 +157,7 @@ class Game(object):
 
         self.saveBestScore()
         print('You won!' if self.board.won() else 'Game Over')
+        return self.score
 
     def getCellStr(self, x, y):
         """
@@ -185,14 +185,14 @@ class Game(object):
         else:
             s = '%3d' % c
 
-        return self.__colors.get(c, Fore.RESET) + s + Fore.RESET
+        return self.__colors.get(c, Fore.RESET) + s + Style.RESET_ALL
 
     def boardToString(self, margins={}):
         """
         return a string representation of the current board.
         """
         b = self.board
-        rg = xrange(b.size())
+        rg = range(b.size())
         left = ' '*margins.get('left', 0)
         s = '\n'.join(
             [left + ' '.join([self.getCellStr(x, y) for x in rg]) for y in rg])
